@@ -18,6 +18,8 @@
 
 #define G_LOG_DOMAIN "dzl-menu-button"
 
+#include "config.h"
+
 #include "app/dzl-application.h"
 #include "bindings/dzl-signal-group.h"
 #include "menus/dzl-menu-button.h"
@@ -189,6 +191,12 @@ dzl_menu_button_set_menu_id (DzlMenuButton *self,
 
   g_return_if_fail (DZL_IS_MENU_BUTTON (self));
 
+  if (menu_id == NULL)
+    {
+      dzl_menu_button_set_model (self, NULL);
+      return;
+    }
+
   app = g_application_get_default ();
 
   if (DZL_IS_APPLICATION (app))
