@@ -4,7 +4,7 @@
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 2.1 of the License, or
+ * the Free Software Foundation, either version 2 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -18,6 +18,8 @@
 
 #define G_LOG_DOMAIN "dzl-shortcut-controller"
 
+#include "config.h"
+
 #include <stdlib.h>
 #include <string.h>
 
@@ -913,6 +915,8 @@ _dzl_shortcut_controller_handle (DzlShortcutController  *self,
       !gtk_widget_is_sensitive (priv->widget))
     DZL_RETURN (DZL_SHORTCUT_MATCH_NONE);
 
+  DZL_TRACE_MSG ("widget = %s, phase = %d", G_OBJECT_TYPE_NAME (priv->widget), phase);
+
   /* Try to dispatch our capture global shortcuts first */
   if (phase == (DZL_SHORTCUT_PHASE_CAPTURE | DZL_SHORTCUT_PHASE_GLOBAL) &&
       dzl_shortcut_controller_is_root (self))
@@ -1087,6 +1091,8 @@ dzl_shortcut_controller_add_command (DzlShortcutController   *self,
 
       if (chord != NULL)
         {
+          DzlShortcutContext *context;
+
           /* Add the chord to our chord table for lookups */
           if (priv->commands_table == NULL)
             priv->commands_table = dzl_shortcut_chord_table_new ();
@@ -1096,6 +1102,11 @@ dzl_shortcut_controller_add_command (DzlShortcutController   *self,
           manager = dzl_shortcut_controller_get_manager (self);
           theme = _dzl_shortcut_manager_get_internal_theme (manager);
           dzl_shortcut_theme_set_chord_for_command (theme, command_id, chord, phase);
+
+          /* Hook things up into the default context */
+          context = _dzl_shortcut_theme_find_default_context_with_phase (theme, priv->widget, phase);
+          if (!_dzl_shortcut_context_contains (context, chord))
+            dzl_shortcut_context_add_command (context, default_accel, command_id);
         }
       else
         g_warning ("\"%s\" is not a valid accelerator chord", default_accel);
