@@ -18,6 +18,8 @@
 
 #define G_LOG_DOMAIN "dzl-shortcut-theme"
 
+#include "config.h"
+
 #include <string.h>
 
 #include "dzl-debug.h"
@@ -352,7 +354,7 @@ dzl_shortcut_theme_add_context (DzlShortcutTheme   *self,
 
   g_return_if_fail (name != NULL);
 
-  g_hash_table_insert (priv->contexts, g_strdup (name), g_object_ref (context));
+  g_hash_table_insert (priv->contexts, (gchar *)g_intern_string (name), g_object_ref (context));
 }
 
 DzlShortcutTheme *
